@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
-our $DATE = '2015-02-24'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2015-03-10'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -293,12 +293,9 @@ sub lint_prereqs {
         }
     }
 
-    my $rfopts = {
-        table_column_orders  => [[qw/module error remedy/]],
-    };
     my $resmeta = {
         "cmdline.exit_code" => @errs ? 500-300:0,
-        result_format_options => {text=>$rfopts, "text-pretty"=>$rfopts},
+        "format_options" => {any=>{table_column_orders=>[[qw/module error remedy/]]}},
     };
     [200, @errs ? "Extraneous/missing dependencies" : "OK", \@errs, $resmeta];
 }
@@ -318,7 +315,7 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.23 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-02-24.
+This document describes version 0.24 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-03-10.
 
 =head1 SYNOPSIS
 
